// @ts-check
// `@type` JSDoc annotations allow editor autocompletion and type checking
// (when paired with `@ts-check`).
// There are various equivalent ways to declare your Docusaurus config.
// See: https://docusaurus.io/docs/api/docusaurus-config

import {themes as prismThemes} from 'prism-react-renderer';

// noinspection CheckImageSize
/** @type {import('@docusaurus/types').Config} */
const config = {
  title: 'jeddunk.xyz',
  tagline: '',
  favicon: 'img/favicon.png',

  // Set the production url of your site here
  url: 'https://jeddunk.xyz',
  // Set the /<baseUrl>/ pathname under which your site is served
  // For GitHub pages deployment, it is often '/<projectName>/'
  baseUrl: '/',

  // GitHub pages deployment config.
  // If you aren't using GitHub pages, you don't need these.
  organizationName: 'jeddunk', // Usually your GitHub org/user name.
  projectName: 'jeddunk.xyz', // Usually your repo name.

  onBrokenLinks: 'throw',
  onBrokenMarkdownLinks: 'warn',

  // Even if you don't use internationalization, you can use this field to set
  // useful metadata like html lang. For example, if your site is Chinese, you
  // may want to replace "en" with "zh-Hans".
  i18n: {
    defaultLocale: 'en',
    locales: ['en'],
  },

  presets: [
    [
      'classic',
      /** @type {import('@docusaurus/preset-classic').Options} */
      ({
        docs: {
          sidebarPath: './sidebars.js',
          // Please change this to your repo.
          // Remove this to remove the "edit this page" links.
          //editUrl:
          //  'https://github.com/facebook/docusaurus/tree/main/packages/create-docusaurus/templates/shared/',
        },
        blog: {
          showReadingTime: false,
          // Please change this to your repo.
          // Remove this to remove the "edit this page" links.
          //editUrl:
          //  'https://github.com/facebook/docusaurus/tree/main/packages/create-docusaurus/templates/shared/',
        },
        theme: {
          customCss: './src/css/custom.scss',
        },
      }),
    ],
  ],

  themeConfig:
    /** @type {import('@docusaurus/preset-classic').ThemeConfig} */
    ({
      // Replace with your project's social card
      image: 'img/docusaurus-social-card.jpg',
      navbar: {
        title: 'jeddunk.xyz',
        logo: {
          alt: 'jeddunk.xyz',
          src: 'img/logo-192.png',
        },
        items: [
          {
            type: 'docSidebar',
            sidebarId: 'defaultSidebar',
            position: 'left',
            label: 'Projects',
          },
          {
            to: '/blog',
            label: 'Blog',
            position: 'left'},
          {
            href: 'https://github.com/facebook/docusaurus',
            label: 'GitHub',
            position: 'right',
          },
        ],
      },
      footer: {
        style: 'dark',
        links: [
          {
            title: 'Docs',
            items: [
              {
                label: 'GoldbergGUI',
                to: '/docs/goldberggui/intro',
              },
              {
                label: 'Auto-CreamAPI 2',
                to: '/docs/autocreamapi/intro',
              },
            ],
          },
          {
            title: 'Community',
            items: [
              {
                label: 'Bluesky',
                href: 'https://bsky.app/profile/jeddunk.xyz',
              },
              {
                label: 'YouTube',
                href: 'https://www.youtube.com/@jeddunkxyz',
              },
              {
                label: 'Twitch',
                href: 'https://twitch.tv/jeddunk',
              },
              {
                label: 'Twitter',
                href: 'https://twitter.com/jeddunk',
              },
            ],
          },
          {
            title: 'More',
            items: [
              {
                label: 'Blog',
                to: '/blog',
              },
              {
                label: 'Git',
                href: 'https://git.jeddunk.xyz/explore/repos',
              },
              {
                label: 'Status',
                href: 'https://status.jeddunk.xyz',
              },
              {
                label: 'Old Homepage',
                href: 'https://old.jeddunk.xyz',
              },
            ],
          },
        ],
        copyright: `<img alt="monkey" src="/img/monkey-face_1f435.png" height="20px" width="20px" ><img alt="pistol" src="/img/pistol_1f52b.png" height="20px" width="20px" >`,
      },
      prism: {
        theme: prismThemes.github,
        darkTheme: prismThemes.dracula,
      },
      colorMode: {
        defaultMode: 'dark',
        disableSwitch: true,
        respectPrefersColorScheme: false
      }
    }),

  plugins: ['docusaurus-plugin-sass'],
};

export default config;
